# Sample images and sources

All rights of these images remain with the original authors. Find the sources below.

![iron-man-portrait](iron-man-portrait.jpg)
iron-man-portrait.jpg: https://www.vincenthie.com/gallery/disney/ironmanportrait
